shades API documentation

# shades

Shades is a python module for generative 2d image creation.

Because of the relatively small level of classes and functions everything is imported into 'shades' name space to avoid long import commands for single items.

View Source

     1"""
     2Shades is a python module for generative 2d image creation.
     3
     4Because of the relatively small level of classes and functions
     5everything is imported into 'shades' name space to avoid
     6long import commands for single items.
     7"""
     8from .canvas import *
     9from .noise_fields import *
    10from .shades import *
    11from .utils import *